@@ -7,6 +7,7 @@ import (
 	"net"
 	"os"
 	"path/filepath"
+	"strings"
 	"time"
 
 	"github.com/containers/common/libnetwork/netavark"
@@ -27,11 +28,8 @@ var _ = Describe("Config", func() {
 	)
 
 	BeforeEach(func() {
-		var err error
-		networkConfDir, err = os.MkdirTemp("", "podman_netavark_test")
-		if err != nil {
-			Fail("Failed to create tmpdir")
-		}
+		t := GinkgoT()
+		networkConfDir = t.TempDir()
 		logBuffer = bytes.Buffer{}
 		logrus.SetOutput(&logBuffer)
 	})
@@ -44,10 +42,6 @@ var _ = Describe("Config", func() {
 		}
 	})
 
-	AfterEach(func() {
-		os.RemoveAll(networkConfDir)
-	})
-
 	Context("basic network config tests", func() {
 		It("check default network config exists", func() {
 			networks, err := libpodNet.NetworkList()
@@ -644,6 +638,35 @@ var _ = Describe("Config", func() {
 			Expect(err).To(HaveOccurred())
 		})
 
+		It("create network with more than max interface name size", func() {
+			name := strings.Repeat("a", types.MaxInterfaceNameLength+1)
+			network := types.Network{
+				NetworkInterface: name,
+			}
+			_, err := libpodNet.NetworkCreate(network, nil)
+			Expect(err).To(HaveOccurred(), "name %s", name)
+		})
+
+		It("should reject interface names with invalid characters", func() {
+			invalidNames := []string{
+				"eth/0",
+				"eth:0",
+				"eth 0",
+				"eth\t0",
+				"eth\n0",
+				"eth\r0",
+				"..",
+				".",
+			}
+			for _, name := range invalidNames {
+				network := types.Network{
+					NetworkInterface: name,
+				}
+				_, err := libpodNet.NetworkCreate(network, nil)
+				Expect(err).To(HaveOccurred(), "name %s", name)
+			}
+		})
+
 		It("create network with ID should fail", func() {
 			id := "17f29b073143d8cd97b5bbe492bdeffec1c5fee55cc1fe2112c8b9335f8b6121"
 			network := types.Network{
@@ -934,6 +957,28 @@ var _ = Describe("Config", func() {
 			Expect(network2.Options).To(HaveKeyWithValue("vlan", "99"))
 		})
 
+		It("create two networks with vlan option and same subnet", func() {
+			subnet := "10.0.0.0/24"
+			n, _ := types.ParseCIDR(subnet)
+			networkOpts := types.Network{
+				Subnets: []types.Subnet{{Subnet: n}},
+			}
+			network1, err := libpodNet.NetworkCreate(networkOpts, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network1.Driver).To(Equal("bridge"))
+			Expect(network1.Subnets).To(HaveLen(1))
+
+			// set a new vlan on the options
+			networkOpts.Options = map[string]string{types.VLANOption: "99"}
+
+			network2, err := libpodNet.NetworkCreate(networkOpts, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network2.Driver).To(Equal("bridge"))
+			Expect(network2.Options).To(HaveKeyWithValue("vlan", "99"))
+			Expect(network2.Subnets).To(HaveLen(1))
+			Expect(network2.Subnets).To(Equal(network1.Subnets))
+		})
+
 		It("create network with vrf option", func() {
 			network := types.Network{
 				Options: map[string]string{
@@ -1034,6 +1079,48 @@ var _ = Describe("Config", func() {
 			Expect(err.Error()).To(ContainSubstring("subnet 10.10.0.0/24 is already used on the host or by another config"))
 		})
 
+		It("create mode=unmanaged network with same subnet", func() {
+			subnet := "10.0.0.0/24"
+			n, _ := types.ParseCIDR(subnet)
+			network := types.Network{
+				Subnets: []types.Subnet{{Subnet: n}},
+			}
+			network1, err := libpodNet.NetworkCreate(network, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network1.Subnets).To(HaveLen(1))
+
+			// creating an network with mode=unmanaged should not cause subnet conflict
+			network = types.Network{
+				Subnets: []types.Subnet{{Subnet: n}},
+				Options: map[string]string{
+					types.ModeOption: types.BridgeModeUnmanaged,
+				},
+			}
+			network2, err := libpodNet.NetworkCreate(network, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network2.Subnets).To(HaveLen(1))
+		})
+
+		It("create mode=unmanaged network with same interface", func() {
+			networkOpts := types.Network{
+				NetworkInterface: "br0",
+				Options: map[string]string{
+					types.ModeOption: types.BridgeModeUnmanaged,
+				},
+			}
+			network1, err := libpodNet.NetworkCreate(networkOpts, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network1.Driver).To(Equal("bridge"))
+			Expect(network1.NetworkInterface).To(Equal("br0"))
+			Expect(network1.Options).To(HaveKeyWithValue("mode", "unmanaged"))
+
+			network2, err := libpodNet.NetworkCreate(networkOpts, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network2.Driver).To(Equal("bridge"))
+			Expect(network2.NetworkInterface).To(Equal("br0"))
+			Expect(network2.Options).To(HaveKeyWithValue("mode", "unmanaged"))
+		})
+
 		It("create macvlan config without subnet", func() {
 			network := types.Network{Driver: "macvlan"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
