@@ -41,11 +41,8 @@ var _ = Describe("Config Local", func() {
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
-		validDirPath, err := os.MkdirTemp("", "config-empty")
-		if err != nil {
-			panic(err)
-		}
-		defer os.RemoveAll(validDirPath)
+		t := GinkgoT()
+		validDirPath := t.TempDir()
 
 		// Given
 		defConf.Network.NetworkConfigDir = validDirPath
@@ -63,11 +60,9 @@ var _ = Describe("Config Local", func() {
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
-		validDirPath, err := os.MkdirTemp("", "config-empty")
-		if err != nil {
-			panic(err)
-		}
-		defer os.RemoveAll(validDirPath)
+		t := GinkgoT()
+		validDirPath := t.TempDir()
+
 		// Given
 		defConf.Network.NetworkConfigDir = validDirPath
 		defConf.Network.CNIPluginDirs.Set([]string{validDirPath})
@@ -356,13 +351,13 @@ var _ = Describe("Config Local", func() {
 		config1, err := New(nil)
 		// Then
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-		gomega.Expect(config1.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/etc/cdi"}))
+		gomega.Expect(config1.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/etc/cdi", "/var/run/cdi"}))
 
 		// Given default just get default
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-		gomega.Expect(config2.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/etc/cdi"}))
+		gomega.Expect(config2.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/etc/cdi", "/var/run/cdi"}))
 
 		// Given override just get override
 		config3, err := NewConfig("testdata/containers_override.conf")
@@ -391,25 +386,19 @@ var _ = Describe("Config Local", func() {
 			"PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
 		}
 		// Given we do
-		oldContainersConf, envSet := os.LookupEnv(containersConfEnv)
-		os.Setenv(containersConfEnv, "/dev/null")
+		t := GinkgoT()
+		t.Setenv(containersConfEnv, "/dev/null")
 
 		// When
-		config, err := Default()
+		config, err := New(nil)
 
-		// Undo that
-		if envSet {
-			os.Setenv(containersConfEnv, oldContainersConf)
-		} else {
-			os.Unsetenv(containersConfEnv)
-		}
 		// Then
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.GetDefaultEnv()).To(gomega.BeEquivalentTo(envs))
 		config.Containers.HTTPProxy = true
 		gomega.Expect(config.GetDefaultEnv()).To(gomega.BeEquivalentTo(envs))
-		os.Setenv("HTTP_PROXY", "localhost")
-		os.Setenv("FOO", "BAR")
+		t.Setenv("HTTP_PROXY", "localhost")
+		t.Setenv("FOO", "BAR")
 		newenvs := []string{"HTTP_PROXY=localhost"}
 		envs = append(newenvs, envs...)
 		gomega.Expect(config.GetDefaultEnv()).To(gomega.BeEquivalentTo(envs))
